pub enum ResultType {
Message(MessageResult),
}Available on crate feature
experimental-search only.Expand description
A single search result, tagged by the kind of entity it represents.
New result kinds will be added as additional variants.
Variants
Message(MessageResult)
A message (room timeline event) matching the query.