pub struct SearchService { /* private fields */ }Available on crate feature
experimental-search only.Expand description
A reactive, paginated search across all the user’s data.
Implementations
Sourceimpl SearchService
impl SearchService
Sourcepub fn new(client: Client) -> Self
pub fn new(client: Client) -> Self
Create a new SearchService for the given client.
Sourcepub async fn set_query(&self, query: String) -> Result<(), SearchError>
pub async fn set_query(&self, query: String) -> Result<(), SearchError>
Set (or update) the search query.
Clears the current results, restarts pagination from scratch and loads
the first page. Call Self::paginate to load any further pages.
Sourcepub fn pagination_state(&self) -> PaginationState
pub fn pagination_state(&self) -> PaginationState
Returns the current pagination state.
Sourcepub fn subscribe_to_pagination_state_updates(
&self,
) -> Subscriber<PaginationState>
pub fn subscribe_to_pagination_state_updates( &self, ) -> Subscriber<PaginationState>
Subscribe to pagination state updates.
Sourcepub async fn results(&self) -> Vec<ResultType>
pub async fn results(&self) -> Vec<ResultType>
Return the current list of results.
Sourcepub async fn subscribe_to_results(
&self,
) -> (Vector<ResultType>, VectorSubscriberBatchedStream<ResultType>)
pub async fn subscribe_to_results( &self, ) -> (Vector<ResultType>, VectorSubscriberBatchedStream<ResultType>)
Subscribe to result list updates.
Sourcepub async fn paginate(&self) -> Result<(), SearchError>
pub async fn paginate(&self) -> Result<(), SearchError>
Load the next page of results, appending them to the list.